# EPAM-Flask

[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/PyCQA/pylint)
[![Build Status](https://app.travis-ci.com/DmytroY/EPAM_Flask.svg?branch=main)](https://app.travis-ci.com/DmytroY/EPAM_Flask)
[![Coverage Status](https://coveralls.io/repos/github/DmytroY/EPAM_Flask/badge.svg?branch=main&kill_cache=1)](https://coveralls.io/github/DmytroY/EPAM_Flask?branch=main)


EPAM Python spring program 2022 self project.
See documentation forder for details

